dhcpkit.ipv6.server.handlers package
====================================

.. automodule:: dhcpkit.ipv6.server.handlers
    :members:
    :undoc-members:
    :show-inheritance:

Submodules
----------

.. toctree::

   dhcpkit.ipv6.server.handlers.basic
   dhcpkit.ipv6.server.handlers.basic_relay
   dhcpkit.ipv6.server.handlers.client_id
   dhcpkit.ipv6.server.handlers.ignore
   dhcpkit.ipv6.server.handlers.interface_id
   dhcpkit.ipv6.server.handlers.preference
   dhcpkit.ipv6.server.handlers.rapid_commit
   dhcpkit.ipv6.server.handlers.server_id
   dhcpkit.ipv6.server.handlers.status_option
   dhcpkit.ipv6.server.handlers.unanswered_ia
   dhcpkit.ipv6.server.handlers.unicast
   dhcpkit.ipv6.server.handlers.utils

